@@ -15,15 +15,11 @@
 ***************************************************************************
 """
 
-__author__ = 'Victor Olaya'
-__date__ = 'August 2012'
-__copyright__ = '(C) 2012, Victor Olaya'
+__author__ = "Victor Olaya"
+__date__ = "August 2012"
+__copyright__ = "(C) 2012, Victor Olaya"
 
-from typing import (
-    Dict,
-    List,
-    Optional
-)
+from typing import Dict, List, Optional
 import os
 import subprocess
 import platform
@@ -49,13 +45,10 @@ from qgis.core import (
     QgsProcessingException,
     QgsProviderRegistry,
     QgsMapLayer,
-    QgsProcessingContext
+    QgsProcessingContext,
 )
 
-from qgis.PyQt.QtCore import (
-    QCoreApplication,
-    QProcess
-)
+from qgis.PyQt.QtCore import QCoreApplication, QProcess
 
 
 @dataclass
@@ -63,35 +56,37 @@ class GdalConnectionDetails:
     """
     Encapsulates connection details for a layer
     """
+
     connection_string: Optional[str] = None
     format: Optional[str] = None
-    open_options: Optional[List[str]] = None
+    open_options: Optional[list[str]] = None
     layer_name: Optional[str] = None
-    credential_options: Optional[Dict] = None
+    credential_options: Optional[dict] = None
 
-    def open_options_as_arguments(self) -> List[str]:
+    def open_options_as_arguments(self) -> list[str]:
         """
         Returns any open options as a list of arguments
         """
         res = []
         for option in self.open_options:
-            res.append(f'-oo {option}')
+            res.append(f"-oo {option}")
 
         return res
 
-    def credential_options_as_arguments(self) -> List[str]:
+    def credential_options_as_arguments(self) -> list[str]:
         """
         Returns any credential options as a list of arguments
         """
         res = []
         for key, value in self.credential_options.items():
-            res.append(f'--config {key} {value}')
+            res.append(f"--config {key} {value}")
 
         return res
 
 
 try:
     from osgeo import gdal, ogr
+
     gdal.UseExceptions()
     ogr.UseExceptions()
 
@@ -101,7 +96,7 @@ except:
 
 
 class GdalUtils:
-    GDAL_HELP_PATH = 'GDAL_HELP_PATH'
+    GDAL_HELP_PATH = "GDAL_HELP_PATH"
 
     supportedRasters = None
     supportedOutputRasters = None
@@ -110,44 +105,50 @@ class GdalUtils:
     def runGdal(commands, feedback=None):
         if feedback is None:
             feedback = QgsProcessingFeedback()
-        envval = os.getenv('PATH')
+        envval = os.getenv("PATH")
         # We need to give some extra hints to get things picked up on OS X
         isDarwin = False
         try:
-            isDarwin = platform.system() == 'Darwin'
+            isDarwin = platform.system() == "Darwin"
         except OSError:  # https://travis-ci.org/m-kuhn/QGIS#L1493-L1526
             pass
-        if isDarwin and os.path.isfile(os.path.join(QgsApplication.prefixPath(), "bin", "gdalinfo")):
+        if isDarwin and os.path.isfile(
+            os.path.join(QgsApplication.prefixPath(), "bin", "gdalinfo")
+        ):
             # Looks like there's a bundled gdal. Let's use it.
-            os.environ['PATH'] = "{}{}{}".format(os.path.join(QgsApplication.prefixPath(), "bin"), os.pathsep, envval)
-            os.environ['DYLD_LIBRARY_PATH'] = os.path.join(QgsApplication.prefixPath(), "lib")
+            os.environ["PATH"] = "{}{}{}".format(
+                os.path.join(QgsApplication.prefixPath(), "bin"), os.pathsep, envval
+            )
+            os.environ["DYLD_LIBRARY_PATH"] = os.path.join(
+                QgsApplication.prefixPath(), "lib"
+            )
         else:
             # Other platforms should use default gdal finder codepath
             settings = QgsSettings()
-            path = settings.value('/GdalTools/gdalPath', '')
+            path = settings.value("/GdalTools/gdalPath", "")
             if not path.lower() in envval.lower().split(os.pathsep):
-                envval += f'{os.pathsep}{path}'
-                os.putenv('PATH', envval)
+                envval += f"{os.pathsep}{path}"
+                os.putenv("PATH", envval)
 
-        fused_command = ' '.join([str(c) for c in commands])
-        QgsMessageLog.logMessage(fused_command, 'Processing', Qgis.MessageLevel.Info)
-        feedback.pushInfo(GdalUtils.tr('GDAL command:'))
+        fused_command = " ".join([str(c) for c in commands])
+        QgsMessageLog.logMessage(fused_command, "Processing", Qgis.MessageLevel.Info)
+        feedback.pushInfo(GdalUtils.tr("GDAL command:"))
         feedback.pushCommandInfo(fused_command)
-        feedback.pushInfo(GdalUtils.tr('GDAL command output:'))
+        feedback.pushInfo(GdalUtils.tr("GDAL command output:"))
 
-        loglines = [GdalUtils.tr('GDAL execution console output')]
+        loglines = [GdalUtils.tr("GDAL execution console output")]
         # create string list of number from 0 to 99
         progress_string_list = [str(a) for a in range(0, 100)]
 
         def on_stdout(ba):
-            val = ba.data().decode('UTF-8')
+            val = ba.data().decode("UTF-8")
             # catch progress reports
-            if val == '100 - done.':
+            if val == "100 - done.":
                 on_stdout.progress = 100
                 feedback.setProgress(on_stdout.progress)
             else:
                 # remove any number of trailing "." or ".." strings
-                match = re.match(r'.*?(\d+)\.+\s*$', val)
+                match = re.match(r".*?(\d+)\.+\s*$", val)
                 found_number = False
                 if match:
                     int_val = match.group(1)
@@ -156,31 +157,31 @@ class GdalUtils:
                         feedback.setProgress(on_stdout.progress)
                         found_number = True
 
-                if not found_number and val == '.':
+                if not found_number and val == ".":
                     on_stdout.progress += 2.5
                     feedback.setProgress(on_stdout.progress)
 
             on_stdout.buffer += val
-            if on_stdout.buffer.endswith('\n') or on_stdout.buffer.endswith('\r'):
+            if on_stdout.buffer.endswith("\n") or on_stdout.buffer.endswith("\r"):
                 # flush buffer
                 feedback.pushConsoleInfo(on_stdout.buffer.rstrip())
                 loglines.append(on_stdout.buffer.rstrip())
-                on_stdout.buffer = ''
+                on_stdout.buffer = ""
 
         on_stdout.progress = 0
-        on_stdout.buffer = ''
+        on_stdout.buffer = ""
 
         def on_stderr(ba):
-            val = ba.data().decode('UTF-8')
+            val = ba.data().decode("UTF-8")
             on_stderr.buffer += val
 
-            if on_stderr.buffer.endswith('\n') or on_stderr.buffer.endswith('\r'):
+            if on_stderr.buffer.endswith("\n") or on_stderr.buffer.endswith("\r"):
                 # flush buffer
                 feedback.reportError(on_stderr.buffer.rstrip())
                 loglines.append(on_stderr.buffer.rstrip())
-                on_stderr.buffer = ''
+                on_stderr.buffer = ""
 
-        on_stderr.buffer = ''
+        on_stderr.buffer = ""
 
         command, *arguments = QgsRunProcess.splitCommand(fused_command)
         proc = QgsBlockingProcess(command, arguments)
@@ -189,15 +190,26 @@ class GdalUtils:
 
         res = proc.run(feedback)
         if feedback.isCanceled() and res != 0:
-            feedback.pushInfo(GdalUtils.tr('Process was canceled and did not complete'))
-        elif not feedback.isCanceled() and proc.exitStatus() == QProcess.ExitStatus.CrashExit:
-            raise QgsProcessingException(GdalUtils.tr('Process was unexpectedly terminated'))
+            feedback.pushInfo(GdalUtils.tr("Process was canceled and did not complete"))
+        elif (
+            not feedback.isCanceled()
+            and proc.exitStatus() == QProcess.ExitStatus.CrashExit
+        ):
+            raise QgsProcessingException(
+                GdalUtils.tr("Process was unexpectedly terminated")
+            )
         elif res == 0:
-            feedback.pushInfo(GdalUtils.tr('Process completed successfully'))
+            feedback.pushInfo(GdalUtils.tr("Process completed successfully"))
         elif proc.processError() == QProcess.ProcessError.FailedToStart:
-            raise QgsProcessingException(GdalUtils.tr('Process {} failed to start. Either {} is missing, or you may have insufficient permissions to run the program.').format(command, command))
+            raise QgsProcessingException(
+                GdalUtils.tr(
+                    "Process {} failed to start. Either {} is missing, or you may have insufficient permissions to run the program."
+                ).format(command, command)
+            )
         else:
-            feedback.reportError(GdalUtils.tr('Process returned error code {}').format(res))
+            feedback.reportError(
+                GdalUtils.tr("Process returned error code {}").format(res)
+            )
 
         return loglines
 
@@ -214,8 +226,8 @@ class GdalUtils:
 
         GdalUtils.supportedRasters = {}
         GdalUtils.supportedOutputRasters = {}
-        GdalUtils.supportedRasters['GTiff'] = ['tif', 'tiff']
-        GdalUtils.supportedOutputRasters['GTiff'] = ['tif', 'tiff']
+        GdalUtils.supportedRasters["GTiff"] = ["tif", "tiff"]
+        GdalUtils.supportedOutputRasters["GTiff"] = ["tif", "tiff"]
 
         for i in range(gdal.GetDriverCount()):
             driver = gdal.GetDriver(i)
@@ -223,19 +235,21 @@ class GdalUtils:
                 continue
             shortName = driver.ShortName
             metadata = driver.GetMetadata()
-            if gdal.DCAP_RASTER not in metadata \
-                    or metadata[gdal.DCAP_RASTER] != 'YES':
+            if gdal.DCAP_RASTER not in metadata or metadata[gdal.DCAP_RASTER] != "YES":
                 continue
 
             if gdal.DMD_EXTENSIONS in metadata:
-                extensions = metadata[gdal.DMD_EXTENSIONS].split(' ')
+                extensions = metadata[gdal.DMD_EXTENSIONS].split(" ")
                 if extensions:
                     GdalUtils.supportedRasters[shortName] = extensions
                     # Only creatable rasters can be referenced in output rasters
-                    if ((gdal.DCAP_CREATE in metadata and
-                         metadata[gdal.DCAP_CREATE] == 'YES') or
-                        (gdal.DCAP_CREATECOPY in metadata and
-                            metadata[gdal.DCAP_CREATECOPY] == 'YES')):
+                    if (
+                        gdal.DCAP_CREATE in metadata
+                        and metadata[gdal.DCAP_CREATE] == "YES"
+                    ) or (
+                        gdal.DCAP_CREATECOPY in metadata
+                        and metadata[gdal.DCAP_CREATECOPY] == "YES"
+                    ):
                         GdalUtils.supportedOutputRasters[shortName] = extensions
 
         return GdalUtils.supportedRasters
@@ -257,10 +271,10 @@ class GdalUtils:
         allexts = []
         for exts in list(GdalUtils.getSupportedRasters().values()):
             for ext in exts:
-                if ext not in allexts and ext not in ['', 'tif', 'tiff']:
+                if ext not in allexts and ext not in ["", "tif", "tiff"]:
                     allexts.append(ext)
         allexts.sort()
-        allexts[0:0] = ['tif', 'tiff']
+        allexts[0:0] = ["tif", "tiff"]
         return allexts
 
     @staticmethod
@@ -268,63 +282,62 @@ class GdalUtils:
         allexts = []
         for exts in list(GdalUtils.getSupportedOutputRasters().values()):
             for ext in exts:
-                if ext not in allexts and ext not in ['', 'tif', 'tiff']:
+                if ext not in allexts and ext not in ["", "tif", "tiff"]:
                     allexts.append(ext)
         allexts.sort()
-        allexts[0:0] = ['tif', 'tiff']
+        allexts[0:0] = ["tif", "tiff"]
         return allexts
 
     @staticmethod
     def getVectorDriverFromFileName(filename):
         ext = os.path.splitext(filename)[1]
-        if ext == '':
-            return 'ESRI Shapefile'
+        if ext == "":
+            return "ESRI Shapefile"
 
         formats = QgsVectorFileWriter.supportedFiltersAndFormats()
         for format in formats:
             if ext in format.filterString:
                 return format.driverName
-        return 'ESRI Shapefile'
+        return "ESRI Shapefile"
 
     @staticmethod
     def getFormatShortNameFromFilename(filename):
-        ext = filename[filename.rfind('.') + 1:]
+        ext = filename[filename.rfind(".") + 1 :]
         supported = GdalUtils.getSupportedRasters()
         for name in list(supported.keys()):
             exts = supported[name]
             if ext in exts:
                 return name
-        return 'GTiff'
+        return "GTiff"
 
     @staticmethod
     def escapeAndJoin(strList):
-        escChars = [' ', '&', '(', ')', '"', ';']
-        joined = ''
+        escChars = [" ", "&", "(", ")", '"', ";"]
+        joined = ""
         for s in strList:
             if not isinstance(s, str):
                 s = str(s)
             # don't escape if command starts with - and isn't a negative number, e.g. -9999
-            if s and re.match(r'^([^-]|-\d)', s) and any(c in s for c in escChars):
-                escaped = '"' + s.replace('\\', '\\\\').replace('"', '"""') \
-                          + '"'
+            if s and re.match(r"^([^-]|-\d)", s) and any(c in s for c in escChars):
+                escaped = '"' + s.replace("\\", "\\\\").replace('"', '"""') + '"'
             else:
                 escaped = s
             if escaped is not None:
-                joined += escaped + ' '
+                joined += escaped + " "
         return joined.strip()
 
     @staticmethod
     def version():
-        return int(gdal.VersionInfo('VERSION_NUM'))
+        return int(gdal.VersionInfo("VERSION_NUM"))
 
     @staticmethod
     def readableVersion():
-        return gdal.VersionInfo('RELEASE_NAME')
+        return gdal.VersionInfo("RELEASE_NAME")
 
     @staticmethod
     def gdal_connection_details_from_uri(
-            uri: str,
-            context: QgsProcessingContext) -> GdalConnectionDetails:
+        uri: str, context: QgsProcessingContext
+    ) -> GdalConnectionDetails:
         """
         Generates GDAL connection details from layer source
         """
@@ -332,10 +345,7 @@ class GdalUtils:
         if layer is None:
             path, ext = os.path.splitext(uri)
             _format = QgsVectorFileWriter.driverForExtension(ext)
-            return GdalConnectionDetails(
-                connection_string=uri,
-                format=f'"{_format}"'
-            )
+            return GdalConnectionDetails(connection_string=uri, format=f'"{_format}"')
 
         return GdalUtils.gdal_connection_details_from_layer(layer)
 
@@ -345,15 +355,14 @@ class GdalUtils:
         Builds GDAL connection details from a QGIS map layer
         """
         provider = layer.providerType()
-        if provider == 'spatialite':
+        if provider == "spatialite":
             # dbname='/geodata/osm_ch.sqlite' table="places" (Geometry) sql=
             regex = re.compile("dbname='(.+)'")
             r = regex.search(str(layer.source()))
             return GdalConnectionDetails(
-                connection_string=r.groups()[0],
-                format='"SQLite"'
+                connection_string=r.groups()[0], format='"SQLite"'
             )
-        elif provider == 'postgres':
+        elif provider == "postgres":
             # dbname='ktryjh_iuuqef' host=spacialdb.com port=9999
             # user='ktryjh_iuuqef' password='xyqwer' sslmode=disable
             # key='gid' estimatedmetadata=true srid=4326 type=MULTIPOLYGON
@@ -366,7 +375,9 @@ class GdalUtils:
                 try:
                     conn = psycopg2.connect(dsUri.connectionInfo())
                 except psycopg2.OperationalError:
-                    (ok, user, passwd) = QgsCredentials.instance().get(conninfo, dsUri.username(), dsUri.password())
+                    (ok, user, passwd) = QgsCredentials.instance().get(
+                        conninfo, dsUri.username(), dsUri.password()
+                    )
                     if not ok:
                         break
 
@@ -374,34 +385,32 @@ class GdalUtils:
                     dsUri.setPassword(passwd)
 
             if not conn:
-                raise RuntimeError('Could not connect to PostgreSQL database - check connection info')
+                raise RuntimeError(
+                    "Could not connect to PostgreSQL database - check connection info"
+                )
 
             if ok:
                 QgsCredentials.instance().put(conninfo, user, passwd)
 
             return GdalConnectionDetails(
-                connection_string=f"PG:{dsUri.connectionInfo()}",
-                format='"PostgreSQL"'
+                connection_string=f"PG:{dsUri.connectionInfo()}", format='"PostgreSQL"'
             )
-        elif provider == 'mssql':
+        elif provider == "mssql":
             # 'dbname=\'db_name\' host=myHost estimatedmetadata=true
             # srid=27700 type=MultiPolygon table="dbo"."my_table"
             # #(Shape) sql='
             dsUri = layer.dataProvider().uri()
-            ogrstr = 'MSSQL:'
-            ogrstr += f'database={dsUri.database()};'
-            ogrstr += f'server={dsUri.host()};'
+            ogrstr = "MSSQL:"
+            ogrstr += f"database={dsUri.database()};"
+            ogrstr += f"server={dsUri.host()};"
             if dsUri.username() != "":
-                ogrstr += f'uid={dsUri.username()};'
+                ogrstr += f"uid={dsUri.username()};"
             else:
-                ogrstr += 'trusted_connection=yes;'
-            if dsUri.password() != '':
-                ogrstr += f'pwd={dsUri.password()};'
-            ogrstr += f'tables={dsUri.table()}'
-            return GdalConnectionDetails(
-                connection_string=ogrstr,
-                format='"MSSQL"'
-            )
+                ogrstr += "trusted_connection=yes;"
+            if dsUri.password() != "":
+                ogrstr += f"pwd={dsUri.password()};"
+            ogrstr += f"tables={dsUri.table()}"
+            return GdalConnectionDetails(connection_string=ogrstr, format='"MSSQL"')
         elif provider == "oracle":
             # OCI:user/password@host:port/service:table
             dsUri = QgsDataSourceUri(layer.dataProvider().dataSourceUri())
@@ -415,7 +424,7 @@ class GdalUtils:
             if dsUri.host() != "":
                 ogrstr += delim + dsUri.host()
                 delim = ""
-                if dsUri.port() not in ["", '1521']:
+                if dsUri.port() not in ["", "1521"]:
                     ogrstr += ":" + dsUri.port()
                 ogrstr += "/"
                 if dsUri.database() != "":
@@ -424,56 +433,50 @@ class GdalUtils:
                 ogrstr += delim + dsUri.database()
 
             if ogrstr == "OCI:":
-                raise RuntimeError('Invalid oracle data source - check connection info')
+                raise RuntimeError("Invalid oracle data source - check connection info")
 
             ogrstr += ":"
             if dsUri.schema() != "":
                 ogrstr += dsUri.schema() + "."
 
             ogrstr += dsUri.table()
-            return GdalConnectionDetails(
-                connection_string=ogrstr,
-                format='"OCI"'
-            )
+            return GdalConnectionDetails(connection_string=ogrstr, format='"OCI"')
         elif provider.lower() == "wfs":
             uri = QgsDataSourceUri(layer.source())
-            baseUrl = uri.param('url').split('?')[0]
+            baseUrl = uri.param("url").split("?")[0]
             return GdalConnectionDetails(
-                connection_string=f"WFS:{baseUrl}",
-                format='"WFS"'
+                connection_string=f"WFS:{baseUrl}", format='"WFS"'
             )
         elif provider.lower() == "ogr":
-            parts = QgsProviderRegistry.instance().decodeUri('ogr',
-                                                             layer.source())
-            if 'path' in parts:
-                path = parts['path']
-                if 'vsiPrefix' in parts:
-                    path = parts['vsiPrefix'] + path
+            parts = QgsProviderRegistry.instance().decodeUri("ogr", layer.source())
+            if "path" in parts:
+                path = parts["path"]
+                if "vsiPrefix" in parts:
+                    path = parts["vsiPrefix"] + path
 
-                _, ext = os.path.splitext(parts['path'])
+                _, ext = os.path.splitext(parts["path"])
                 format = QgsVectorFileWriter.driverForExtension(ext)
 
                 return GdalConnectionDetails(
                     connection_string=path,
                     format=f'"{format}"',
-                    open_options=parts.get('openOptions', None),
-                    credential_options=parts.get('credentialOptions', None)
+                    open_options=parts.get("openOptions", None),
+                    credential_options=parts.get("credentialOptions", None),
                 )
         elif provider.lower() == "gdal":
-            parts = QgsProviderRegistry.instance().decodeUri('gdal',
-                                                             layer.source())
-            if 'path' in parts:
-                path = parts['path']
-                if 'vsiPrefix' in parts:
-                    path = parts['vsiPrefix'] + path
+            parts = QgsProviderRegistry.instance().decodeUri("gdal", layer.source())
+            if "path" in parts:
+                path = parts["path"]
+                if "vsiPrefix" in parts:
+                    path = parts["vsiPrefix"] + path
 
                 return GdalConnectionDetails(
                     connection_string=path,
-                    open_options=parts.get('openOptions', None),
-                    credential_options=parts.get('credentialOptions', None)
+                    open_options=parts.get("openOptions", None),
+                    credential_options=parts.get("credentialOptions", None),
                 )
-        elif provider == 'postgresraster':
-            gdal_source = ''
+        elif provider == "postgresraster":
+            gdal_source = ""
             uri = layer.dataProvider().uri()
             gdal_source = f"PG: {uri.connectionInfo()}"
             schema = uri.schema()
@@ -481,28 +484,28 @@ class GdalUtils:
                 gdal_source += f" schema='{schema}'"
             table = uri.table()
             gdal_source += f" table='{table}'"
-            column = uri.param('column') or uri.geometryColumn()
+            column = uri.param("column") or uri.geometryColumn()
             if column:
                 gdal_source += f" column='{column}'"
-            is_tiled = any([layer.dataProvider().xSize() != layer.dataProvider().xBlockSize(),
-                            layer.dataProvider().ySize() != layer.dataProvider().yBlockSize()])
+            is_tiled = any(
+                [
+                    layer.dataProvider().xSize() != layer.dataProvider().xBlockSize(),
+                    layer.dataProvider().ySize() != layer.dataProvider().yBlockSize(),
+                ]
+            )
             gdal_source += f" mode={2 if is_tiled else 1}"
             where = layer.dataProvider().subsetString()
             if where:
                 gdal_source += f" where='{where}'"
 
             return GdalConnectionDetails(
-                connection_string=gdal_source,
-                format='"PostGISRaster"'
+                connection_string=gdal_source, format='"PostGISRaster"'
             )
 
         ogrstr = str(layer.source()).split("|")[0]
         path, ext = os.path.splitext(ogrstr)
         format = QgsVectorFileWriter.driverForExtension(ext)
-        return GdalConnectionDetails(
-            connection_string=ogrstr,
-            format=f'"{format}"'
-        )
+        return GdalConnectionDetails(connection_string=ogrstr, format=f'"{format}"')
 
     @staticmethod
     def ogrOutputLayerName(uri):
@@ -512,31 +515,31 @@ class GdalUtils:
     @staticmethod
     def ogrLayerName(uri):
         uri = uri.strip('"')
-        if ' table=' in uri:
+        if " table=" in uri:
             # table="schema"."table"
             re_table_schema = re.compile(' table="([^"]*)"\\."([^"]*)"')
             r = re_table_schema.search(uri)
             if r:
-                return r.groups()[0] + '.' + r.groups()[1]
+                return r.groups()[0] + "." + r.groups()[1]
             # table="table"
             re_table = re.compile(' table="([^"]*)"')
             r = re_table.search(uri)
             if r:
                 return r.groups()[0]
-        elif 'layername' in uri:
-            regex = re.compile('(layername=)([^|]*)')
+        elif "layername" in uri:
+            regex = re.compile("(layername=)([^|]*)")
             r = regex.search(uri)
             return r.groups()[1]
 
-        fields = uri.split('|')
+        fields = uri.split("|")
         basePath = fields[0]
         fields = fields[1:]
         layerid = 0
         for f in fields:
-            if f.startswith('layername='):
-                return f.split('=')[1]
-            if f.startswith('layerid='):
-                layerid = int(f.split('=')[1])
+            if f.startswith("layername="):
+                return f.split("=")[1]
+            if f.startswith("layerid="):
+                layerid = int(f.split("=")[1])
 
         try:
             ds = gdal.OpenEx(basePath, gdal.OF_VECTOR)
@@ -553,14 +556,16 @@ class GdalUtils:
 
     @staticmethod
     def parseCreationOptions(value):
-        parts = value.split('|')
+        parts = value.split("|")
         options = []
         for p in parts:
-            options.extend(['-co', p])
+            options.extend(["-co", p])
         return options
 
     @staticmethod
-    def writeLayerParameterToTextFile(filename, alg, parameters, parameter_name, context, quote=True, executing=False):
+    def writeLayerParameterToTextFile(
+        filename, alg, parameters, parameter_name, context, quote=True, executing=False
+    ):
         listFile = QgsProcessingUtils.generateTempFilename(filename, context)
 
         if executing:
@@ -572,8 +577,8 @@ class GdalUtils:
                 else:
                     layers.append(layer_details.connection_string)
 
-            with open(listFile, 'w') as f:
-                f.write('\n'.join(layers))
+            with open(listFile, "w") as f:
+                f.write("\n".join(layers))
 
         return listFile
 
@@ -585,13 +590,17 @@ class GdalUtils:
         :param crs: crs to convert
         :return: gdal friendly string
         """
-        if crs.authid().upper().startswith('EPSG:') or crs.authid().upper().startswith('IGNF:') or crs.authid().upper().startswith('ESRI:'):
+        if (
+            crs.authid().upper().startswith("EPSG:")
+            or crs.authid().upper().startswith("IGNF:")
+            or crs.authid().upper().startswith("ESRI:")
+        ):
             return crs.authid()
 
         return crs.toWkt(QgsCoordinateReferenceSystem.WktVariant.WKT_PREFERRED_GDAL)
 
     @classmethod
-    def tr(cls, string, context=''):
-        if context == '':
+    def tr(cls, string, context=""):
+        if context == "":
             context = cls.__name__
         return QCoreApplication.translate(context, string)
